@@ -248,6 +248,21 @@ class ACLHoundClient(object):
         """
         run(['git', 'branch'])
 
+    def task_edit(self, args):
+        """
+        Switch to git branch to continue work
+
+        Usage: aclhound [-d] task edit <taskname>
+
+        Arguments:
+          <taskname>
+            Name of the task you are working on.
+            Use 'aclhound task list' to see local tasks.
+
+        """
+        run(['git', 'checkout', args['<taskname>']])
+
+
     def task(self, args):
         """
         Start, continue or submit a piece of work for review.
@@ -364,39 +379,57 @@ overview of previous work")
         Note: please ensure you run 'diff' inside your ACLHound data directory
         """
         print(args)
+        print("ERROR: 'diff' not implemented yet")
 
     def build(self, args):
         """
         Show unified build between last commit and current state.
 
         Usage: aclhound build <devicename>
+               aclhound build all
 
         Arguments:
           <devicename>
             The device file for which a network config must be generated.
 
+          <all>
+            Build all network policies into their respective vendor specific
+            representation. Useful as 'review' test in Jenkins.
+
         Note: please ensure you run 'build' inside your ACLHound data directory
         """
-        filename = args['<devicename>'].encode('ascii', 'ignore')
-        with open(filename, 'r') as f:
-            for line in f:
-                line = line.strip()
-                if line.split(' ')[0] == "vendor":
-                    vendor = line.split(' ')[1]
-                elif line.split(' ')[0] == "include":
-                    polname = line.split(' ')[1]
-                    print("")
-                    print("")
-                    print("Seed policy name: %s" % polname)
-                    print("   IPv4:")
-                    for line in generate_policy(polname, afi=4,
-                                                vendor=vendor).split('\n'):
-                        print("   %s" % line)
-                    print("     ---------")
-                    print("   IPv6:")
-                    for line in generate_policy(polname, afi=6,
-                                                vendor=vendor).split('\n'):
-                        print("   %s" % line)
+        if args['<devicename>'] == "all":
+            import glob
+            devices_list = set(glob.glob('devices/*')) - \
+                set(glob.glob('devices/*.ignore'))
+        else:
+            devices_list = [args['<devicename>'].encode('ascii', 'ignore')]
+
+        def go_build(filename):
+            print("INFO: building configuration for %s" % filename)
+            with open(filename, 'r') as f:
+                for line in f:
+                    line = line.strip()
+                    if line.split(' ')[0] == "vendor":
+                        vendor = line.split(' ')[1]
+                    elif line.split(' ')[0] == "include":
+                        polname = line.split(' ')[1]
+                        print("")
+                        print("")
+                        print("Seed policy name: %s" % polname)
+                        print("   IPv4:")
+                        for line in generate_policy(polname, afi=4,
+                                                    vendor=vendor).split('\n'):
+                            print("   %s" % line)
+                        print("     ---------")
+                        print("   IPv6:")
+                        for line in generate_policy(polname, afi=6,
+                                                    vendor=vendor).split('\n'):
+                            print("   %s" % line)
+            print("")
+
+        for device in devices_list:
+            go_build(device)
 
     def deploy(self, args):
         """
